@@ -14,9 +14,11 @@ pub use self::Tick::*;
 pub use self::BorderLocation2D::*;
 pub use self::LegendOption::*;
 pub use self::ContourStyle::*;
+pub use self::PaletteType::*;
 
 /// An enumeration of plot options you can supply to plotting commands, governing
 /// things like line width, color and others
+#[deriving(Copy)]
 pub enum PlotOption<'l>
 {
 	/// Sets the symbol used for points. The valid characters are as follows:
@@ -61,6 +63,7 @@ pub enum PlotOption<'l>
 }
 
 /// An enumeration of possible fill regions
+#[deriving(Copy)]
 pub enum FillRegionType
 {
 	Above,
@@ -69,6 +72,7 @@ pub enum FillRegionType
 }
 
 /// An enumeration of possible text and label alignments
+#[deriving(Copy)]
 pub enum AlignType
 {
 	AlignLeft,
@@ -79,6 +83,7 @@ pub enum AlignType
 }
 
 /// An enumeration of possible dash styles
+#[deriving(Copy)]
 pub enum DashType
 {
 	Solid,
@@ -106,6 +111,7 @@ impl DashType
 }
 
 /// An enumeration of possible arrow head styles
+#[deriving(Copy)]
 pub enum ArrowheadType
 {
 	/// An arrow head shaped like a 'V'
@@ -120,6 +126,7 @@ pub enum ArrowheadType
 
 /// An enumeration of something that can either be fixed (e.g. the maximum of X values),
 /// or automatically determined
+#[deriving(Copy)]
 pub enum AutoOption<T>
 {
 	/// Fixes the value to a specific value
@@ -142,6 +149,7 @@ impl<T> AutoOption<T>
 }
 
 /// An enumeration of label options that control label attributes
+#[deriving(Copy)]
 pub enum LabelOption<'l>
 {
 	/// Sets the offset of the label in characters
@@ -180,6 +188,7 @@ pub enum LabelOption<'l>
 }
 
 /// An enumeration of axis tick options
+#[deriving(Copy)]
 pub enum TickOption
 {
 	/// Specifies whether the ticks are drawn at the borders of the plot, or on the axis
@@ -204,6 +213,7 @@ pub enum Tick<T>
 }
 
 /// Plot border locations
+#[deriving(Copy)]
 pub enum BorderLocation2D
 {
 	Bottom = 1,
@@ -213,6 +223,7 @@ pub enum BorderLocation2D
 }
 
 /// Legend options
+#[deriving(Copy)]
 pub enum LegendOption<'l>
 {
 	/// Puts curve samples to the left of the label
@@ -233,6 +244,7 @@ pub enum LegendOption<'l>
 }
 
 /// Specifies how the contours are drawn
+#[deriving(Copy)]
 pub enum ContourStyle
 {
 	/// Draw lines between points of equal value
@@ -250,3 +262,27 @@ pub enum ContourStyle
 	/// order of the polynomial (clamped to range from 2 to 10).
 	Spline(u32, u32)
 }
+
+/// Specifies what sort of palette to use
+#[deriving(Copy)]
+pub enum PaletteType
+{
+	/// Use a gray palette with a specified gamma
+	Gray(f32),
+	/// Use a palette with that uses a predefined formula for each color component.
+	/// Each formula is identified by an integer between [-36, 36]. See gnuplot documentation, or use the pre-defined constants.
+	Formula(i32, i32, i32),
+	/// Use a cube helix palette, with a certain start (in radians), cycles, saturation and gamma.
+	CubeHelix(f32, f32, f32, f32),
+}
+
+/// A gray palette
+pub const GRAY: PaletteType = Gray(1.0);
+/// Default Gnuplot palette
+pub const COLOR: PaletteType = Formula(3, 11, 16);
+/// Classic rainbow palette with terrible perceptual properties
+pub const RAINBOW: PaletteType = Formula(33, 13, 10);
+/// A black body palette
+pub const HOT: PaletteType = Formula(34, 35, 36);
+/// A nice default for a cube helix
+pub const HELIX: PaletteType = CubeHelix(0.5, -0.8, 2.0, 1.0);
